==> tuia-advert-center-api-1.7.7-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/app/RspAppPackDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.app;

import java.io.Serializable;
import java.util.List;

/**
 * Created by lizhihui on 2017-07-07 15:25.
 */
public class RspAppPackDto implements Serializable {
    private static final long serialVersionUID = -4733653871243256534L;
    //包id
    private Long id;
    //媒体包包名
    private String name;

    //媒体包描述
    private String description;
    //媒体包中媒体(app)的数量
    private Integer appCount;

    //无效应用数量
    private Integer unableCount;

    /**
     *报表相关条件
     */
    private String reportRef;

    /**
     * 今日是否自动更新 0-未更新，1-更新
     */
    private Integer updateStatus;

    /**
     * 流量包規則
     */
    private String appRegular;

    public String getReportRef() {
        return reportRef;
    }

    public void setReportRef(String reportRef) {
        this.reportRef = reportRef;
    }

    public Integer getUpdateStatus() {
        return updateStatus;
    }

    public void setUpdateStatus(Integer updateStatus) {
        this.updateStatus = updateStatus;
    }

    private List<RspAppSimpleInfoDto> appList;

    public List<RspAppSimpleInfoDto> getAppList() {
        return appList;
    }

    public void setAppList(List<RspAppSimpleInfoDto> appList) {
        this.appList = appList;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getAppCount() {
        return appCount;
    }

    public void setAppCount(Integer appCount) {
        this.appCount = appCount;
    }

    public Integer getUnableCount() {
        return unableCount;
    }

    public void setUnableCount(Integer unableCount) {
        this.unableCount = unableCount;
    }

    public String getAppRegular() {
        return appRegular;
    }

    public void setAppRegular(String appRegular) {
        this.appRegular = appRegular;
    }
}

==> tuia-advert-center-api-2.3.37-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/app/RspAppPackDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.app;

import java.io.Serializable;
import java.util.List;

/**
 * Created by lizhihui on 2017-07-07 15:25.
 */
public class RspAppPackDto implements Serializable {
    private static final long serialVersionUID = -4733653871243256534L;
    //包id
    private Long id;
    //媒体包包名
    private String name;

    //媒体包描述
    private String description;
    //媒体包中媒体(app)的数量
    private Integer appCount;

    //无效应用数量
    private Integer unableCount;

    /**
     *报表相关条件
     */
    private String reportRef;

    /**
     * 今日是否自动更新 0-未更新，1-更新
     */
    private Integer updateStatus;

    /**
     * 流量包規則
     */
    private String appRegular;

    /*** true: 规则包，false: 人工包 ***/
    private Boolean hasRegular;

    /** 流量包推荐状态 0 未推荐，1推荐*/
    private Integer validateStatus;

    public String getReportRef() {
        return reportRef;
    }

    /** 流量包更新状态 0自动更新,1手动更新*/
    private Integer operateType;

    public void setReportRef(String reportRef) {
        this.reportRef = reportRef;
    }

    public Integer getUpdateStatus() {
        return updateStatus;
    }

    public void setUpdateStatus(Integer updateStatus) {
        this.updateStatus = updateStatus;
    }

    private List<RspAppSimpleInfoDto> appList;

    public List<RspAppSimpleInfoDto> getAppList() {
        return appList;
    }

    public void setAppList(List<RspAppSimpleInfoDto> appList) {
        this.appList = appList;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getAppCount() {
        return appCount;
    }

    public void setAppCount(Integer appCount) {
        this.appCount = appCount;
    }

    public Integer getUnableCount() {
        return unableCount;
    }

    public void setUnableCount(Integer unableCount) {
        this.unableCount = unableCount;
    }

    public String getAppRegular() {
        return appRegular;
    }

    public void setAppRegular(String appRegular) {
        this.appRegular = appRegular;
    }

    public Boolean getHasRegular() {
        return hasRegular;
    }

    public void setHasRegular(Boolean hasRegular) {
        this.hasRegular = hasRegular;
    }

    public Integer getValidateStatus() {
        return validateStatus;
    }

    public void setValidateStatus(Integer validateStatus) {
        this.validateStatus = validateStatus;
    }

    public Integer getOperateType() {
        return operateType;
    }

    public void setOperateType(Integer operateType) {
        this.operateType = operateType;
    }
}
